"""Installer"""
import os
import shutil
import stat
from setuptools import setup
from setuptools.command.install import install

NAME = 'Greenhouseui'
VERSION = '5'
AUTHOR = 'Thomas Klaehn'
EMAIL = 'tkl@blackfinn.de'
PACKAGES = ['greenhouseui']
REQUIRES = ['Flask', 'gunicorn', 'matplotlib']
PACKAGE_DATA = {'greenhouseui': ['templates/*', 'static/css/*', 'static/scripts/*']}

SERVICEDIR = "/lib/systemd/system"
DAEMON_START_SCRIPT = os.path.join(SERVICEDIR, 'greenhouseui.service')

LOGFILE = "/var/log/greenhouseui.log"

class Install(install):
    """Installer"""
    def run(self):
        install.run(self)
        os.makedirs(SERVICEDIR, exist_ok=True)
        shutil.copyfile('greenhouseui.service', os.path.join(SERVICEDIR, DAEMON_START_SCRIPT))
        os.chmod(DAEMON_START_SCRIPT, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)

        try:
            open(LOGFILE, 'r', encoding="UTF-8")
        except FileNotFoundError:
            os.makedirs(os.path.dirname(LOGFILE), exist_ok=True)
            open(LOGFILE, 'x', encoding="UTF-8")
            os.chmod(LOGFILE, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP |
                     stat.S_IWGRP | stat.S_IROTH | stat.S_IWOTH)


setup(name=NAME, version=VERSION, long_description=__doc__, author=AUTHOR,
      author_email=EMAIL, packages=PACKAGES, include_package_data=True,
      package_data=PACKAGE_DATA, zip_safe=False, install_requires=REQUIRES,
      cmdclass={'install': Install})
